@@ -103,7 +103,7 @@ class SQLiteAdaptor(object):
     def get_limit_query(self, limit, offset):
         if offset and offset > 0:
             limit = limit - offset
-        return f" LIMIT {limit}"
+        return f" LIMIT {limit if limit >=0 else 0}"
 
     def get_select_query(self, base, *args, **kwargs):
         query = "SELECT %s FROM %s" % (', '.join(base.fieldnames), base.tablename)
@@ -247,11 +247,17 @@ class SQLiteAdaptor(object):
             query += ' DEFAULT %s' % field.default
         return query
 
-    def get_text_field_create_query(self):
-        return '%s TEXT'
+    def get_text_field_create_query(self, field):
+        query = '%s TEXT'
+        if field.default is not None:
+            query += ' NOT NULL DEFAULT "%s"' % field.default
+        return query
 
     def get_text_field_create_column_query(self, field):
-        return 'ALTER TABLE %%s ADD COLUMN %s TEXT' % (field.fieldname)
+        query = 'ALTER TABLE %%s ADD COLUMN %s TEXT' % (field.fieldname)
+        if field.default is not None:
+            query += ' NOT NULL DEFAULT "%s"' % field.default
+        return query
 
     def get_datetime_field_create_query(self, default):
         if default is None:
